@@ -10,17 +10,17 @@
 """
 
 from .utils import dumps_list
+from .base_classes import BaseLaTeXContainer
 
+class SectionBase(BaseLaTeXContainer):
 
-class Section:
+    """A class that is the base for all section type classes"""
 
-    """A class that represents a section."""
-
-    def __init__(self, title, numbering=True):
+    def __init__(self, title, numbering=True, data=None):
         self.title = title
         self.numbering = numbering
 
-        self.content = []
+        super().__init__(data)
 
     def dumps(self):
         """Represents the section as a string in LaTeX syntax."""
@@ -29,5 +29,20 @@ class Section:
         else:
             num = ''
 
-        base = r'\section' + num + '{' + self.title + '}\n'
-        return base + dumps_list(self.content)
+        base = '\\' + self.__class__.__name__.lower() + num
+        return base + '{' + self.title + '}\n' + dumps_list(self)
+
+
+class Section(SectionBase):
+
+    """A class that represents a section."""
+
+
+class Subsection(SectionBase):
+
+    """A class that represents a subsection."""
+
+
+class Subsubsection(SectionBase):
+
+    """A class that represents a subsubsection."""
